@@ -63,9 +63,9 @@ class ProgressBar(object):
                 st += str(round(1/ips, 2)) + ' s/item'
 
         sys.stdout.write(
-            f'{f"{str(self.completed).rjust(int(log(50,10)+.5))}/{self.items}" if self.items else ""} \
+            f'\r{f"{str(self.completed).rjust(int(log(50,10)+.5))}/{self.items}" if self.items else ""} \
 {str(round(self.pos*100,2)).ljust(5)}% \
-[{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t\r')
+[{(self.char*int(self.pos*self.maxlen)).ljust(self.maxlen)}] {st}\t')
 
     def update(self, completed=None):
         if completed == None:
@@ -88,7 +88,6 @@ class ProgressBar(object):
 
 
 if __name__ == '__main__':
-    import random
-    prog = ProgressBar(5, show_on_update=True, ips=1.5)
+    prog = ProgressBar(10000, show_on_update=True, ips=1.5)
     for i in range(prog.items):
         prog.update(i+1)
